@@ -5,6 +5,7 @@
 # @Software: PyCharm
 # @Email   ：liwudi@liwudi.fun
 import sys
+import time
 
 from PaperCrawlerUtil.constant import *
 from PaperCrawlerUtil.common_util import *
@@ -15,6 +16,8 @@ import pymysql
 
 class ResearchRecord(object):
     """
+    通过在程序中调用该对象方法，在数据库中记录参数，运行的文件， 运行的时间等信息
+    也提供了基本的数据库操作的封装和导出，也可以执行自定义SQL
     目前，数据库和表都是限定的固定值，之后再改
     """
 
@@ -37,6 +40,8 @@ class ResearchRecord(object):
                 remote_bind_address=('localhost', db_conf["ssl_db_port"])
             )
             self.ssl.start()
+        else:
+            self.ssl = None
 
         self.db_url = "127.0.0.1" if check_ssl else db_conf["db_url"]
         self.db_username = db_conf["db_username"]
@@ -60,6 +65,7 @@ class ResearchRecord(object):
         返回建表建数据库语句
         :return:
         """
+        log(CREATE_DB_TABLE)
         return CREATE_DB_TABLE
 
     def create_db_conn(self):
@@ -71,7 +77,8 @@ class ResearchRecord(object):
                                      user=self.db_username,
                                      password=self.db_pass,
                                      db=self.db_database,
-                                     port=self.port
+                                     port=self.port,
+                                     charset="utf8"
                                      )
         self.conn = connection
         self.conn.autocommit(True)
@@ -79,6 +86,7 @@ class ResearchRecord(object):
     def _execute(self, sql: str) -> bool:
         """
         内部方法，执行sql
+        也可以执行用户自定义的sql，比如利用建表时默认的四个默认列记录数据等
         :param sql: 待执行的sql
         :return:
         """
@@ -91,16 +99,19 @@ class ResearchRecord(object):
                 write_file(local_path_generate("", "record_error.log"), mode="a+", string=sql + "\n")
             return False
 
-    def insert(self, file: str, exec_time: str) -> tuple:
+    def insert(self, file: str, exec_time: str, args: str = "") -> tuple:
         """
         插入，初始化记录，记录执行的文件，开始的时间
+        :param args: 运行参数
         :param file: 执行的文件，使用__file__即可
         :param exec_time: 开始执行的时间
         :return:
         """
         exec_time = exec_time if len(exec_time) > 0 else get_timestamp()
-        sql = "insert into `{}`.`{}`(`file_execute`, `excute_time`) " \
-              "values ('{}', '{}')".format(self.db_database, self.db_table, file, exec_time)
+        sql = "insert into `{}`.`{}`(`file_execute`, `excute_time`, `args`) " \
+              "values ('{}', '{}','{}')".format(self.db_database, self.db_table,
+                                                pymysql.converters.escape_string(file), exec_time,
+                                                pymysql.converters.escape_string(args))
         if self._execute(sql):
             sql = "select   id   from  " + self.db_database + "." + self.db_table + \
                   " order   by   id   desc   limit   1"
@@ -111,17 +122,21 @@ class ResearchRecord(object):
         else:
             return -1,
 
-    def update(self, id: int, finish_time: str = "", result: str = "") -> bool:
+    def update(self, id: int, finish_time: str = "", result: str = "", remark: str = "") -> bool:
         """
         执行结束之后，使用该方法更新
+        :param remark: 备注
+        :param args: 运行参数
         :param id: 要更新的记录id，可以从插入方法的返回值获得
         :param finish_time: 结束的时间
         :param result: 执行的结果
         :return:
         """
         finish_time = finish_time if len(finish_time) > 0 else get_timestamp()
-        sql = "update `" + self.db_database + "." + self.db_table + "` set result='{}', finish_time='{}' where id = {}". \
-            format(result, finish_time, str(id))
+        sql = "update `" + self.db_database + "`.`" + self.db_table + \
+              "` set result='{}', finish_time='{}', other='{}' where id = {}". \
+                  format(pymysql.converters.escape_string(result), finish_time,
+                         pymysql.converters.escape_string(remark), str(id))
         if self._execute(sql):
             return True
         else:
@@ -229,12 +244,17 @@ class ResearchRecord(object):
             return False
 
     def __del__(self):
+        """
+        关闭连接，不知道为什么调用的时候加（）会报错，比如self.ssl.stop（），会报错
+        TypeError: 'NoneType' object is not callable
+        :return:
+        """
         if self.ssl is not None:
-            self.ssl.close()
+            self.ssl.stop
         if self.conn is not None:
-            self.conn.close()
+            self.conn.close
         if self.cursor is not None:
-            self.cursor.close()
+            self.cursor.close
 
 
 if __name__ == "__main__":
